GPUDevice class
- Available extensions
- Annotations
-
- @JS()
- @staticInterop
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- queue → JSObject
-
Available on GPUDevice, provided by the GPUDeviceImport extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createBindGroup(
JSObject descriptor) → JSObject -
Available on GPUDevice, provided by the GPUDeviceImport extension
-
createCommandEncoder(
) → JSObject -
Available on GPUDevice, provided by the GPUDeviceImport extension
-
createComputePipeline(
JSObject descriptor) → JSObject -
Available on GPUDevice, provided by the GPUDeviceImport extension
-
createShaderModule(
JSObject descriptor) → JSObject -
Available on GPUDevice, provided by the GPUDeviceImport extension
-
importExternalTexture(
JSObject descriptor) → JSObject -
Available on GPUDevice, provided by the GPUDeviceImport extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited