mgpuInitializeContext function
Implementation
Future<void> mgpuInitializeContext() async {
// Everything else in this library assumes an initialized context, so this
// is the one choke point where the module itself must be up first.
await ensureMinigpuModuleLoaded();
await ccall(
"mgpuInitializeContext".toJS,
"void".toJS,
<JSAny>[].toJS,
<JSAny>[].toJS,
{"async": true}.toJSDeep,
).toDart;
}